import listEditor from 'wiki-list-editor';
import axios from 'axios';
import qs from 'querystring'

import './styles.scss';

function addSaver(editor, saveUrl, page, beforeSave) {
    return {
        save() {
            return editor.save().then(outputData => {
                beforeSave()
                let data = {
                    'json': 1,
                    'p': page,
                    'summary': "JSON test",
                    'content': JSON.stringify(outputData),
                };
                return axios.post(saveUrl, qs.encode(data))
            })
        }
    }
}

function Indicator(element, timeout) {
    let timeoutId;

    return {
        done() {
            timeoutId = setTimeout(() => {
                element.classList.add('hidden')
            }, timeout*1000);
        },

        setText(text) {
            if (timeoutId) {
                clearTimeout(timeoutId);
                timeoutId = null;
            }
            element.innerText = text;
            element.classList.remove('hidden')
        },
    }
}

function addIndicator(editor, indicator) {
    return {
        save() {
            editor.save().then(() => {
                indicator.setText('saved!');
                indicator.done();
            })
        }
    }
}


let holder = document.getElementById('editor');
let editor = listEditor(holder, JSON.parse(holder.dataset.input));

editor.on('change', function () {
    let element = document.getElementById('editor');
    let indicator = Indicator(document.getElementById('save-indicator'), 2);
    let saveUrl = element.dataset.saveurl;
    let page = element.dataset.page;

    indicator.setText('has changes...');
    addIndicator(
        addSaver(editor, saveUrl, page, () => indicator.setText('saving...')),
        indicator
    ).save()
})
